@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<SEC_CTRL_USB_HS_MEM_RULE_SPEC>> for R {
+impl From<crate::R<SEC_CTRL_USB_HS_MEM_RULE_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<SEC_CTRL_USB_HS_MEM_RULE_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<SEC_CTRL_USB_HS_MEM_RULE_SPEC>> for W {
+impl From<crate::W<SEC_CTRL_USB_HS_MEM_RULE_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<SEC_CTRL_USB_HS_MEM_RULE_SPEC>) -> Self {
         W(writer)
     }
@@ -54,6 +56,7 @@ impl From<SRAM_SECT_0_RULE_A> for u8 {
 #[doc = "Field `SRAM_SECT_0_RULE` reader - Address space: 0x4010_0000 - 0x4010_0FFF"]
 pub struct SRAM_SECT_0_RULE_R(crate::FieldReader<u8, SRAM_SECT_0_RULE_A>);
 impl SRAM_SECT_0_RULE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SRAM_SECT_0_RULE_R(crate::FieldReader::new(bits))
     }
@@ -155,6 +158,7 @@ impl From<SRAM_SECT_1_RULE_A> for u8 {
 #[doc = "Field `SRAM_SECT_1_RULE` reader - Address space: 0x4010_1000 - 0x4010_1FFF"]
 pub struct SRAM_SECT_1_RULE_R(crate::FieldReader<u8, SRAM_SECT_1_RULE_A>);
 impl SRAM_SECT_1_RULE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SRAM_SECT_1_RULE_R(crate::FieldReader::new(bits))
     }
@@ -256,6 +260,7 @@ impl From<SRAM_SECT_2_RULE_A> for u8 {
 #[doc = "Field `SRAM_SECT_2_RULE` reader - Address space: 0x4010_2000 - 0x4010_2FFF"]
 pub struct SRAM_SECT_2_RULE_R(crate::FieldReader<u8, SRAM_SECT_2_RULE_A>);
 impl SRAM_SECT_2_RULE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SRAM_SECT_2_RULE_R(crate::FieldReader::new(bits))
     }
@@ -357,6 +362,7 @@ impl From<SRAM_SECT_3_RULE_A> for u8 {
 #[doc = "Field `SRAM_SECT_3_RULE` reader - Address space: 0x4010_3000 - 0x4010_3FFF"]
 pub struct SRAM_SECT_3_RULE_R(crate::FieldReader<u8, SRAM_SECT_3_RULE_A>);
 impl SRAM_SECT_3_RULE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         SRAM_SECT_3_RULE_R(crate::FieldReader::new(bits))
     }
@@ -480,6 +486,7 @@ impl W {
         SRAM_SECT_3_RULE_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
