@@ -6,92 +6,92 @@ pub struct RegisterBlock {
     #[doc = "0x04 - puf discharge time in ms."]
     pub puf_discharge_time_in_ms:
         crate::Reg<puf_discharge_time_in_ms::PUF_DISCHARGE_TIME_IN_MS_SPEC>,
-    #[doc = "0x08 - ."]
+    #[doc = "0x08..0x4b0 - ."]
     pub activation_code: [crate::Reg<activation_code::ACTIVATION_CODE_SPEC>; 298],
-    _reserved_3_sbkey: [u8; 4usize],
-    _reserved_4_sbkey: [u8; 4usize],
-    _reserved_5_sbkey: [u8; 4usize],
-    _reserved_6_sbkey: [u8; 4usize],
-    _reserved_7_sbkey: [u8; 4usize],
-    _reserved_8_sbkey: [u8; 4usize],
-    _reserved_9_sbkey: [u8; 4usize],
-    _reserved_10_sbkey: [u8; 4usize],
-    _reserved_11_sbkey: [u8; 4usize],
-    _reserved_12_sbkey: [u8; 4usize],
-    _reserved_13_sbkey: [u8; 4usize],
-    _reserved_14_sbkey: [u8; 4usize],
-    _reserved_15_sbkey: [u8; 4usize],
-    _reserved_16_sbkey: [u8; 4usize],
-    _reserved_17_user_kek: [u8; 4usize],
-    _reserved_18_user_kek: [u8; 4usize],
-    _reserved_19_user_kek: [u8; 4usize],
-    _reserved_20_user_kek: [u8; 4usize],
-    _reserved_21_user_kek: [u8; 4usize],
-    _reserved_22_user_kek: [u8; 4usize],
-    _reserved_23_user_kek: [u8; 4usize],
-    _reserved_24_user_kek: [u8; 4usize],
-    _reserved_25_user_kek: [u8; 4usize],
-    _reserved_26_user_kek: [u8; 4usize],
-    _reserved_27_user_kek: [u8; 4usize],
-    _reserved_28_user_kek: [u8; 4usize],
-    _reserved_29_user_kek: [u8; 4usize],
-    _reserved_30_user_kek: [u8; 4usize],
-    _reserved_31_uds: [u8; 4usize],
-    _reserved_32_uds: [u8; 4usize],
-    _reserved_33_uds: [u8; 4usize],
-    _reserved_34_uds: [u8; 4usize],
-    _reserved_35_uds: [u8; 4usize],
-    _reserved_36_uds: [u8; 4usize],
-    _reserved_37_uds: [u8; 4usize],
-    _reserved_38_uds: [u8; 4usize],
-    _reserved_39_uds: [u8; 4usize],
-    _reserved_40_uds: [u8; 4usize],
-    _reserved_41_uds: [u8; 4usize],
-    _reserved_42_uds: [u8; 4usize],
-    _reserved_43_uds: [u8; 4usize],
-    _reserved_44_uds: [u8; 4usize],
-    _reserved_45_prince_region0: [u8; 4usize],
-    _reserved_46_prince_region0: [u8; 4usize],
-    _reserved_47_prince_region0: [u8; 4usize],
-    _reserved_48_prince_region0: [u8; 4usize],
-    _reserved_49_prince_region0: [u8; 4usize],
-    _reserved_50_prince_region0: [u8; 4usize],
-    _reserved_51_prince_region0: [u8; 4usize],
-    _reserved_52_prince_region0: [u8; 4usize],
-    _reserved_53_prince_region0: [u8; 4usize],
-    _reserved_54_prince_region0: [u8; 4usize],
-    _reserved_55_prince_region0: [u8; 4usize],
-    _reserved_56_prince_region0: [u8; 4usize],
-    _reserved_57_prince_region0: [u8; 4usize],
-    _reserved_58_prince_region0: [u8; 4usize],
-    _reserved_59_prince_region1: [u8; 4usize],
-    _reserved_60_prince_region1: [u8; 4usize],
-    _reserved_61_prince_region1: [u8; 4usize],
-    _reserved_62_prince_region1: [u8; 4usize],
-    _reserved_63_prince_region1: [u8; 4usize],
-    _reserved_64_prince_region1: [u8; 4usize],
-    _reserved_65_prince_region1: [u8; 4usize],
-    _reserved_66_prince_region1: [u8; 4usize],
-    _reserved_67_prince_region1: [u8; 4usize],
-    _reserved_68_prince_region1: [u8; 4usize],
-    _reserved_69_prince_region1: [u8; 4usize],
-    _reserved_70_prince_region1: [u8; 4usize],
-    _reserved_71_prince_region1: [u8; 4usize],
-    _reserved_72_prince_region1: [u8; 4usize],
-    _reserved_73_prince_region2: [u8; 4usize],
-    _reserved_74_prince_region2: [u8; 4usize],
-    _reserved_75_prince_region2: [u8; 4usize],
-    _reserved_76_prince_region2: [u8; 4usize],
-    _reserved_77_prince_region2: [u8; 4usize],
-    _reserved_78_prince_region2: [u8; 4usize],
-    _reserved_79_prince_region2: [u8; 4usize],
-    _reserved_80_prince_region2: [u8; 4usize],
-    _reserved_81_prince_region2: [u8; 4usize],
-    _reserved_82_prince_region2: [u8; 4usize],
-    _reserved_83_prince_region2: [u8; 4usize],
-    _reserved_84_prince_region2: [u8; 4usize],
-    _reserved_85_prince_region2: [u8; 4usize],
-    _reserved_86_prince_region2: [u8; 4usize],
+    _reserved_3_sbkey: [u8; 0x04],
+    _reserved_4_sbkey: [u8; 0x04],
+    _reserved_5_sbkey: [u8; 0x04],
+    _reserved_6_sbkey: [u8; 0x04],
+    _reserved_7_sbkey: [u8; 0x04],
+    _reserved_8_sbkey: [u8; 0x04],
+    _reserved_9_sbkey: [u8; 0x04],
+    _reserved_10_sbkey: [u8; 0x04],
+    _reserved_11_sbkey: [u8; 0x04],
+    _reserved_12_sbkey: [u8; 0x04],
+    _reserved_13_sbkey: [u8; 0x04],
+    _reserved_14_sbkey: [u8; 0x04],
+    _reserved_15_sbkey: [u8; 0x04],
+    _reserved_16_sbkey: [u8; 0x04],
+    _reserved_17_user_kek: [u8; 0x04],
+    _reserved_18_user_kek: [u8; 0x04],
+    _reserved_19_user_kek: [u8; 0x04],
+    _reserved_20_user_kek: [u8; 0x04],
+    _reserved_21_user_kek: [u8; 0x04],
+    _reserved_22_user_kek: [u8; 0x04],
+    _reserved_23_user_kek: [u8; 0x04],
+    _reserved_24_user_kek: [u8; 0x04],
+    _reserved_25_user_kek: [u8; 0x04],
+    _reserved_26_user_kek: [u8; 0x04],
+    _reserved_27_user_kek: [u8; 0x04],
+    _reserved_28_user_kek: [u8; 0x04],
+    _reserved_29_user_kek: [u8; 0x04],
+    _reserved_30_user_kek: [u8; 0x04],
+    _reserved_31_uds: [u8; 0x04],
+    _reserved_32_uds: [u8; 0x04],
+    _reserved_33_uds: [u8; 0x04],
+    _reserved_34_uds: [u8; 0x04],
+    _reserved_35_uds: [u8; 0x04],
+    _reserved_36_uds: [u8; 0x04],
+    _reserved_37_uds: [u8; 0x04],
+    _reserved_38_uds: [u8; 0x04],
+    _reserved_39_uds: [u8; 0x04],
+    _reserved_40_uds: [u8; 0x04],
+    _reserved_41_uds: [u8; 0x04],
+    _reserved_42_uds: [u8; 0x04],
+    _reserved_43_uds: [u8; 0x04],
+    _reserved_44_uds: [u8; 0x04],
+    _reserved_45_prince_region0: [u8; 0x04],
+    _reserved_46_prince_region0: [u8; 0x04],
+    _reserved_47_prince_region0: [u8; 0x04],
+    _reserved_48_prince_region0: [u8; 0x04],
+    _reserved_49_prince_region0: [u8; 0x04],
+    _reserved_50_prince_region0: [u8; 0x04],
+    _reserved_51_prince_region0: [u8; 0x04],
+    _reserved_52_prince_region0: [u8; 0x04],
+    _reserved_53_prince_region0: [u8; 0x04],
+    _reserved_54_prince_region0: [u8; 0x04],
+    _reserved_55_prince_region0: [u8; 0x04],
+    _reserved_56_prince_region0: [u8; 0x04],
+    _reserved_57_prince_region0: [u8; 0x04],
+    _reserved_58_prince_region0: [u8; 0x04],
+    _reserved_59_prince_region1: [u8; 0x04],
+    _reserved_60_prince_region1: [u8; 0x04],
+    _reserved_61_prince_region1: [u8; 0x04],
+    _reserved_62_prince_region1: [u8; 0x04],
+    _reserved_63_prince_region1: [u8; 0x04],
+    _reserved_64_prince_region1: [u8; 0x04],
+    _reserved_65_prince_region1: [u8; 0x04],
+    _reserved_66_prince_region1: [u8; 0x04],
+    _reserved_67_prince_region1: [u8; 0x04],
+    _reserved_68_prince_region1: [u8; 0x04],
+    _reserved_69_prince_region1: [u8; 0x04],
+    _reserved_70_prince_region1: [u8; 0x04],
+    _reserved_71_prince_region1: [u8; 0x04],
+    _reserved_72_prince_region1: [u8; 0x04],
+    _reserved_73_prince_region2: [u8; 0x04],
+    _reserved_74_prince_region2: [u8; 0x04],
+    _reserved_75_prince_region2: [u8; 0x04],
+    _reserved_76_prince_region2: [u8; 0x04],
+    _reserved_77_prince_region2: [u8; 0x04],
+    _reserved_78_prince_region2: [u8; 0x04],
+    _reserved_79_prince_region2: [u8; 0x04],
+    _reserved_80_prince_region2: [u8; 0x04],
+    _reserved_81_prince_region2: [u8; 0x04],
+    _reserved_82_prince_region2: [u8; 0x04],
+    _reserved_83_prince_region2: [u8; 0x04],
+    _reserved_84_prince_region2: [u8; 0x04],
+    _reserved_85_prince_region2: [u8; 0x04],
+    _reserved_86_prince_region2: [u8; 0x04],
 }
 impl RegisterBlock {
     #[doc = "0x4b0 - ."]
