@@ -7,7 +7,8 @@ impl core::ops::Deref for R {
         &self.0
     }
 }
-impl core::convert::From<crate::R<CFG_SPEC>> for R {
+impl From<crate::R<CFG_SPEC>> for R {
+    #[inline(always)]
     fn from(reader: crate::R<CFG_SPEC>) -> Self {
         R(reader)
     }
@@ -27,7 +28,8 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<CFG_SPEC>> for W {
+impl From<crate::W<CFG_SPEC>> for W {
+    #[inline(always)]
     fn from(writer: crate::W<CFG_SPEC>) -> Self {
         W(writer)
     }
@@ -49,6 +51,7 @@ impl From<MSTEN_A> for bool {
 #[doc = "Field `MSTEN` reader - Master Enable. When disabled, configurations settings for the Master function are not changed, but the Master function is internally reset."]
 pub struct MSTEN_R(crate::FieldReader<bool, MSTEN_A>);
 impl MSTEN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MSTEN_R(crate::FieldReader::new(bits))
     }
@@ -132,6 +135,7 @@ impl From<SLVEN_A> for bool {
 #[doc = "Field `SLVEN` reader - Slave Enable. When disabled, configurations settings for the Slave function are not changed, but the Slave function is internally reset."]
 pub struct SLVEN_R(crate::FieldReader<bool, SLVEN_A>);
 impl SLVEN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLVEN_R(crate::FieldReader::new(bits))
     }
@@ -215,6 +219,7 @@ impl From<MONEN_A> for bool {
 #[doc = "Field `MONEN` reader - Monitor Enable. When disabled, configurations settings for the Monitor function are not changed, but the Monitor function is internally reset."]
 pub struct MONEN_R(crate::FieldReader<bool, MONEN_A>);
 impl MONEN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MONEN_R(crate::FieldReader::new(bits))
     }
@@ -298,6 +303,7 @@ impl From<TIMEOUTEN_A> for bool {
 #[doc = "Field `TIMEOUTEN` reader - I2C bus Time-out Enable. When disabled, the time-out function is internally reset."]
 pub struct TIMEOUTEN_R(crate::FieldReader<bool, TIMEOUTEN_A>);
 impl TIMEOUTEN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TIMEOUTEN_R(crate::FieldReader::new(bits))
     }
@@ -381,6 +387,7 @@ impl From<MONCLKSTR_A> for bool {
 #[doc = "Field `MONCLKSTR` reader - Monitor function Clock Stretching."]
 pub struct MONCLKSTR_R(crate::FieldReader<bool, MONCLKSTR_A>);
 impl MONCLKSTR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MONCLKSTR_R(crate::FieldReader::new(bits))
     }
@@ -464,6 +471,7 @@ impl From<HSCAPABLE_A> for bool {
 #[doc = "Field `HSCAPABLE` reader - High-speed mode Capable enable. Since High Speed mode alters the way I2C pins drive and filter, as well as the timing for certain I2C signalling, enabling High-speed mode applies to all functions: Master, Slave, and Monitor."]
 pub struct HSCAPABLE_R(crate::FieldReader<bool, HSCAPABLE_A>);
 impl HSCAPABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         HSCAPABLE_R(crate::FieldReader::new(bits))
     }
@@ -594,6 +602,7 @@ impl W {
         HSCAPABLE_W { w: self }
     }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
