@@ -1,21 +1,22 @@
-#[doc = "Register `PIO1_19` reader"]
-pub struct R(crate::R<PIO1_19_SPEC>);
+#[doc = "Register `PIO0_5` reader"]
+pub struct R(crate::R<PIO0_5_SPEC>);
 impl core::ops::Deref for R {
-    type Target = crate::R<PIO1_19_SPEC>;
+    type Target = crate::R<PIO0_5_SPEC>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-impl core::convert::From<crate::R<PIO1_19_SPEC>> for R {
-    fn from(reader: crate::R<PIO1_19_SPEC>) -> Self {
+impl From<crate::R<PIO0_5_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<PIO0_5_SPEC>) -> Self {
         R(reader)
     }
 }
-#[doc = "Register `PIO1_19` writer"]
-pub struct W(crate::W<PIO1_19_SPEC>);
+#[doc = "Register `PIO0_5` writer"]
+pub struct W(crate::W<PIO0_5_SPEC>);
 impl core::ops::Deref for W {
-    type Target = crate::W<PIO1_19_SPEC>;
+    type Target = crate::W<PIO0_5_SPEC>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -27,8 +28,9 @@ impl core::ops::DerefMut for W {
         &mut self.0
     }
 }
-impl core::convert::From<crate::W<PIO1_19_SPEC>> for W {
-    fn from(writer: crate::W<PIO1_19_SPEC>) -> Self {
+impl From<crate::W<PIO0_5_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<PIO0_5_SPEC>) -> Self {
         W(writer)
     }
 }
@@ -62,6 +64,7 @@ impl From<FUNC_A> for u8 {
 #[doc = "Field `FUNC` reader - Selects pin function."]
 pub struct FUNC_R(crate::FieldReader<u8, FUNC_A>);
 impl FUNC_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         FUNC_R(crate::FieldReader::new(bits))
     }
@@ -185,7 +188,7 @@ impl<'a> FUNC_W<'a> {
         self.w
     }
 }
-#[doc = "Selects function mode (on-chip pull-up/pull-down resistor control).\n\nValue on reset: 0"]
+#[doc = "Selects function mode (on-chip pull-up/pull-down resistor control).\n\nValue on reset: 2"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
 pub enum MODE_A {
@@ -207,6 +210,7 @@ impl From<MODE_A> for u8 {
 #[doc = "Field `MODE` reader - Selects function mode (on-chip pull-up/pull-down resistor control)."]
 pub struct MODE_R(crate::FieldReader<u8, MODE_A>);
 impl MODE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         MODE_R(crate::FieldReader::new(bits))
     }
@@ -303,6 +307,7 @@ impl From<SLEW_A> for bool {
 #[doc = "Field `SLEW` reader - Driver slew rate."]
 pub struct SLEW_R(crate::FieldReader<bool, SLEW_A>);
 impl SLEW_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLEW_R(crate::FieldReader::new(bits))
     }
@@ -386,6 +391,7 @@ impl From<INVERT_A> for bool {
 #[doc = "Field `INVERT` reader - Input polarity."]
 pub struct INVERT_R(crate::FieldReader<bool, INVERT_A>);
 impl INVERT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INVERT_R(crate::FieldReader::new(bits))
     }
@@ -452,7 +458,7 @@ impl<'a> INVERT_W<'a> {
         self.w
     }
 }
-#[doc = "Select Digital mode.\n\nValue on reset: 0"]
+#[doc = "Select Digital mode.\n\nValue on reset: 1"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DIGIMODE_A {
     #[doc = "0: Disable digital mode. Digital input set to 0."]
@@ -469,6 +475,7 @@ impl From<DIGIMODE_A> for bool {
 #[doc = "Field `DIGIMODE` reader - Select Digital mode."]
 pub struct DIGIMODE_R(crate::FieldReader<bool, DIGIMODE_A>);
 impl DIGIMODE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DIGIMODE_R(crate::FieldReader::new(bits))
     }
@@ -552,6 +559,7 @@ impl From<OD_A> for bool {
 #[doc = "Field `OD` reader - Controls open-drain mode."]
 pub struct OD_R(crate::FieldReader<bool, OD_A>);
 impl OD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OD_R(crate::FieldReader::new(bits))
     }
@@ -618,89 +626,6 @@ impl<'a> OD_W<'a> {
         self.w
     }
 }
-#[doc = "Analog switch input control.\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ASW_A {
-    #[doc = "0: For pins PIO0_9, PIO0_11, PIO0_12, PIO0_15, PIO0_18, PIO0_31, PIO1_0 and PIO1_9, analog switch is closed (enabled). For the other pins, analog switch is open (disabled)."]
-    VALUE0 = 0,
-    #[doc = "1: For all pins except PIO0_9, PIO0_11, PIO0_12, PIO0_15, PIO0_18, PIO0_31, PIO1_0 and PIO1_9 analog switch is closed (enabled)"]
-    VALUE1 = 1,
-}
-impl From<ASW_A> for bool {
-    #[inline(always)]
-    fn from(variant: ASW_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ASW` reader - Analog switch input control."]
-pub struct ASW_R(crate::FieldReader<bool, ASW_A>);
-impl ASW_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ASW_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ASW_A {
-        match self.bits {
-            false => ASW_A::VALUE0,
-            true => ASW_A::VALUE1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `VALUE0`"]
-    #[inline(always)]
-    pub fn is_value0(&self) -> bool {
-        **self == ASW_A::VALUE0
-    }
-    #[doc = "Checks if the value of the field is `VALUE1`"]
-    #[inline(always)]
-    pub fn is_value1(&self) -> bool {
-        **self == ASW_A::VALUE1
-    }
-}
-impl core::ops::Deref for ASW_R {
-    type Target = crate::FieldReader<bool, ASW_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `ASW` writer - Analog switch input control."]
-pub struct ASW_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ASW_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ASW_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "For pins PIO0_9, PIO0_11, PIO0_12, PIO0_15, PIO0_18, PIO0_31, PIO1_0 and PIO1_9, analog switch is closed (enabled). For the other pins, analog switch is open (disabled)."]
-    #[inline(always)]
-    pub fn value0(self) -> &'a mut W {
-        self.variant(ASW_A::VALUE0)
-    }
-    #[doc = "For all pins except PIO0_9, PIO0_11, PIO0_12, PIO0_15, PIO0_18, PIO0_31, PIO1_0 and PIO1_9 analog switch is closed (enabled)"]
-    #[inline(always)]
-    pub fn value1(self) -> &'a mut W {
-        self.variant(ASW_A::VALUE1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bits 0:3 - Selects pin function."]
     #[inline(always)]
@@ -732,11 +657,6 @@ impl R {
     pub fn od(&self) -> OD_R {
         OD_R::new(((self.bits >> 9) & 0x01) != 0)
     }
-    #[doc = "Bit 10 - Analog switch input control."]
-    #[inline(always)]
-    pub fn asw(&self) -> ASW_R {
-        ASW_R::new(((self.bits >> 10) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bits 0:3 - Selects pin function."]
@@ -769,34 +689,30 @@ impl W {
     pub fn od(&mut self) -> OD_W {
         OD_W { w: self }
     }
-    #[doc = "Bit 10 - Analog switch input control."]
-    #[inline(always)]
-    pub fn asw(&mut self) -> ASW_W {
-        ASW_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
         self.0.bits(bits);
         self
     }
 }
-#[doc = "Digital I/O control for port 1 pins PIO1_19\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pio1_19](index.html) module"]
-pub struct PIO1_19_SPEC;
-impl crate::RegisterSpec for PIO1_19_SPEC {
+#[doc = "Digital I/O control for port 0 pins PIO0_5\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pio0_5](index.html) module"]
+pub struct PIO0_5_SPEC;
+impl crate::RegisterSpec for PIO0_5_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [pio1_19::R](R) reader structure"]
-impl crate::Readable for PIO1_19_SPEC {
+#[doc = "`read()` method returns [pio0_5::R](R) reader structure"]
+impl crate::Readable for PIO0_5_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [pio1_19::W](W) writer structure"]
-impl crate::Writable for PIO1_19_SPEC {
+#[doc = "`write(|w| ..)` method takes [pio0_5::W](W) writer structure"]
+impl crate::Writable for PIO0_5_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets PIO1_19 to value 0"]
-impl crate::Resettable for PIO1_19_SPEC {
+#[doc = "`reset()` method sets PIO0_5 to value 0x0120"]
+impl crate::Resettable for PIO0_5_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0
+        0x0120
     }
 }
